#!/bin/sh
# $Copyright$
# Copyright (C) Fujitsu Technology Solutions 2011, 2012
# All rights reserved
#
# ssm.sh - Script for running the ServerView System Monitor in Linux

echo "Info: SV System Monitor start script"

#
# (1) Check DISPLAY variable for display relocation
#

if [ -z $DISPLAY ]; then
    echo "Error: X11 DISPLAY variable is empty. Please set it to :0.0 or similar."
    exit
fi

field1=`echo "$DISPLAY" | cut -d':' -f 1`
# echo "field1=-->$field1<--"

if [ "pre$field1" != "pre" ]; then
    # echo "field1 is NOT empty"
    echo "Error: Display relocation isn't supported. Please reset your DISPLAY variable."
    exit
fi

#
# (2) Check java version
#

# Minimal required major and minor version number (V1.6)
req_major=1
req_minor=6

# Current major and minor version number
current_major=0
current_minor=0

temp_file=/tmp/java_version_tmp.txt

# Check if java interpreter exists
if java -version > $temp_file 2>&1; then
    echo "Info: Java interpreter was found."
else
    echo "Error: Cannot find java interpreter."
    exit
fi

# Check if java interpreter has at least the required version
if cat $temp_file | grep "java version" > /dev/null 2>&1; then
    echo "Info: Found string 'java version'"
else
    echo "Error: Cannot find string 'java version'."
    exit
fi

# Get version string, remove quotes and get major and minor version numbers
current_version=`cat $temp_file | grep "java version" | cut -d' ' -f 3`
# echo "\$current_version=$current_version"

current_version=`echo $current_version | sed 's/^"*//;s/"*$//'`
# echo "\$current_version=$current_version"

# Use only major and minor version numbers
current_major=`echo $current_version | cut -d'.' -f 1`
current_minor=`echo $current_version | cut -d'.' -f 2`

# echo "\$req_major=$req_major"
# echo "\$req_minor=$req_minor"
# echo "\$current_major=$current_major"
# echo "\$current_minor=$current_minor"

# Compare major and minor version numbers
if [ $current_major -gt $req_major ]; then
    # echo "$current_major > $req_major"
    echo "Info: Current java version is ok: $current_major.$current_minor >= $req_major.$req_minor"
elif [ $current_major -eq $req_major ]; then
    # echo "$current_major = $req_major"
    if [ $current_minor -ge $req_minor ]; then
        # echo "$current_minor >= $req_minor"
        echo "Info: Current java version is ok: $current_major.$current_minor >= $req_major.$req_minor"
    else
        # echo "$current_minor < $req_minor"
        echo "Error: Current java version is too old: $current_major.$current_minor < $req_major.$req_minor"
        exit
    fi
else
    # echo "$current_major < $req_major"
    echo "Error: Current java version is too old: $current_major.$current_minor < $req_major.$req_minor"
    exit
fi

# Delete temp file if it exists
if [ -f $temp_file ]; then
    rm $temp_file
fi

#
# (3) Check system language and prepare ssm_lang parameter
#

found_lang="false"
for arg in "$@"
do
    case "$arg" in
    lang=*)
        echo "Info: Parameter lang= was found in parameter list."
        found_lang="true"
    ;;
    esac
done

# echo "Info: found_lang = $found_lang"
# echo "Info: LC_ALL = -->$LC_ALL<--"
# echo "Info: LANG   = -->$LANG<--"

# Set ssm_lang dependent on LC_ALL or LANG variable
ssm_lang=""

# First try LC_ALL
ssm_lang=${LC_ALL%%_*}

# If LC_ALL is empty, try LANG
if [ -z $ssm_lang ]; then
    # echo "Info: System language was not found in \$LC_ALL, trying \$LANG."
    ssm_lang=${LANG%%_*}

    # If ssm_lang is still empty, try date command and keyboard file
    # On VMware {LC_ALL|LANG} is not correctly set, so test if date contains JST
    if [ -z $ssm_lang ]; then
        echo "Info: System language was neither found in \$LC_ALL nor \$LANG."
        echo "Info: Checking for japanese date and keyboard."
        date | fgrep JST > /dev/null
        if [ $? = 0 ]; then
            ssm_lang=ja
        else # last chance
            fgrep KEYTABLE=\"jp  /etc/sysconfig/keyboard && ssm_lang=ja
        fi
    else
        echo "Info: System language was found in \$LANG."
    fi
else
    echo "Info: System language was found in \$LC_ALL."
fi

# If French language fr was found, change it to fr_CA for SSM call
if [ "$ssm_lang" = "fr" ]; then
    ssm_lang="fr_CA"
fi

# If ssm_lang is still empty use english as default
if [ -z $ssm_lang ]; then
    echo "Warning: System language was not found, defaulting to English."
    ssm_lang=en
fi

#
# (4) Start the SV System Monitor
#

if [ "$found_lang" = "true" ]; then
    echo "Info: Using lang from parameter list."
    java -jar /opt/fujitsu/ServerViewSuite/SSM/SSM.jar $@ &
else
    echo "Info: Using lang $ssm_lang."
    java -jar /opt/fujitsu/ServerViewSuite/SSM/SSM.jar lang=$ssm_lang $@ &
fi

